@@ -19,7 +19,7 @@ import json
 import os
 
 
-class cash:
+class Cash:
     def __init__(self):
         self.tx = pd.DataFrame()
         self.token = ""
@@ -35,9 +35,9 @@ class cash:
         return self.tx
 
 
-class account:
+class Account:
     def __init__(self,jaye):
-        self.cash = cash()
+        self.cash = Cash()
         self.is_login = False
         self.myinfo = {}
         self.jaye = jaye
@@ -74,7 +74,7 @@ class account:
             STRATEGIES = response.json()
 
             for i in STRATEGIES:
-                self.jaye.trade[i] = strategy(i,user_token)
+                self.jaye.trade[i] = Strategy(i, user_token)
             self.jaye.trade["strategies"] = STRATEGIES
 
             trade_tuple = namedtuple('trade', ["strategies"] + STRATEGIES)
@@ -82,7 +82,7 @@ class account:
 
             # insert token
             self.cash.token = user_token
-            self.jaye.analysis.token = user_token
+            self.jaye.Analysis.token = user_token
             self.is_login = True
 
             CONSOLE.log("login complete")
@@ -91,17 +91,17 @@ class account:
         with CONSOLE.status("[bold #584eca]Working on tasks...") as status:
             url = BASE_URL_ACCOUNT + '/accounts/logout/'
             response = requests.post(url)
-            self.cash = cash()
+            self.cash = Cash()
             self.is_login = False
             self.myinfo = {}
             # parents instance jaye
-            self.jaye.analysis = analysis()
+            self.jaye.Analysis = Analysis()
             self.jaye.trade = {}
             # self.jaye.simulation = simulation()
 
             # CONSOLE.log("logout complete")
 
-class analysis:
+class Analysis:
     def __init__(self):
         self.token = ''
         pass
@@ -198,7 +198,7 @@ class analysis:
             # CONSOLE.log("analysis.market complete")
             return df_market
 
-class strategy:
+class Strategy:
     def __init__(self,name,token):
         self.strategy_name = name
         self.token = token
@@ -242,7 +242,7 @@ class strategy:
             return df_allocation
 
 
-class simulation:
+class Simulation:
     def __init__(self):
         pass
 
